package com.gic.haoban.manage.service.service.out.impl.role;

import com.gic.api.base.commons.ServiceResponse;
import com.gic.haoban.base.api.common.pojo.dto.WebLoginDTO;
import com.gic.haoban.manage.api.dto.qdto.role.HaobanRoleQDTO;
import com.gic.haoban.manage.api.service.role.HaobanRoleApiService;
import com.gic.haoban.manage.service.entity.role.TabHaobanMenu;
import com.gic.haoban.manage.service.entity.role.TabHaobanRole;
import com.gic.haoban.manage.service.pojo.bo.role.HaobanRoleBO;
import com.gic.haoban.manage.service.service.role.HaobanMenuService;
import com.gic.haoban.manage.service.service.role.HaobanRoleService;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.ArrayList;
import java.util.List;

@Service
public class HaobanRoleApiServiceImpl implements HaobanRoleApiService {
    private static final Logger logger = LogManager.getLogger(HaobanRoleApiServiceImpl.class);

    @Autowired
    private HaobanRoleService haobanRoleService;
    @Autowired
    private HaobanMenuService haobanMenuService;

    @Override
    @Transactional(rollbackFor = Exception.class)
    public ServiceResponse add(HaobanRoleQDTO haobanRoleQDTO, WebLoginDTO login) {
        List<Long> menuIds = haobanRoleQDTO.getMenuIds();
        List<TabHaobanRole> haobanRoles = new ArrayList<>();
        for (Long menuId : menuIds) {
            TabHaobanRole tabHaobanRole = new TabHaobanRole();
            tabHaobanRole.setRoleName(haobanRoleQDTO.getRoleName());
            tabHaobanRole.setMenuId(menuId);
            tabHaobanRole.setClerkType(haobanRoleQDTO.getClerkType());
            tabHaobanRole.setStatusFlag(1);
            tabHaobanRole.setEnterpriseId(login.getEnterpriseId());
            tabHaobanRole.setWxEnterpriseId(login.getWxEnterpriseId());
            TabHaobanMenu tabHaobanMenu = haobanMenuService.queryById(menuId);
            if (tabHaobanMenu != null) {
                tabHaobanRole.setMenuCode(tabHaobanMenu.getMenuCode());
                tabHaobanRole.setMenuName(tabHaobanMenu.getMenuName());
            }
            tabHaobanRole.setCreatorId(login.getClerkId());
            tabHaobanRole.setCreatorName(login.getClerkName());
            haobanRoles.add(tabHaobanRole);
        }
        return ServiceResponse.success(haobanRoleService.insertBatch(haobanRoles));
    }


    @Override
    @Transactional(rollbackFor = Exception.class)
    public ServiceResponse edit(HaobanRoleQDTO haobanRoleQDTO, WebLoginDTO login) {
        String enterpriseId = login.getEnterpriseId();
        String wxEnterpriseId = login.getWxEnterpriseId();
        Integer clerkType = haobanRoleQDTO.getClerkType();
        List<Long> delMenuIds = haobanRoleQDTO.getDelMenuIds();
        List<Long> delRoleIds = haobanRoleService.queryByUnMenuIds(delMenuIds, enterpriseId, wxEnterpriseId, clerkType);
        //删除已删除的权限
        haobanRoleService.delByRoleIds(delRoleIds);
        List<Long> menuIds = haobanRoleQDTO.getMenuIds();
        for (Long menuId : menuIds) {
            Long roleId = haobanRoleService.queryByMenuId(menuId, enterpriseId, wxEnterpriseId, clerkType);
            if (roleId == null) {
                TabHaobanRole tabHaobanRole = new TabHaobanRole();
                tabHaobanRole.setRoleName(haobanRoleQDTO.getRoleName());
                tabHaobanRole.setMenuId(menuId);
                tabHaobanRole.setClerkType(haobanRoleQDTO.getClerkType());
                tabHaobanRole.setStatusFlag(1);
                tabHaobanRole.setEnterpriseId(login.getEnterpriseId());
                tabHaobanRole.setWxEnterpriseId(login.getWxEnterpriseId());
                TabHaobanMenu tabHaobanMenu = haobanMenuService.queryById(menuId);
                if (tabHaobanMenu != null) {
                    tabHaobanRole.setMenuCode(tabHaobanMenu.getMenuCode());
                    tabHaobanRole.setMenuName(tabHaobanMenu.getMenuName());
                }
                tabHaobanRole.setCreatorId(login.getClerkId());
                tabHaobanRole.setCreatorName(login.getClerkName());
                haobanRoleService.insert(tabHaobanRole);
            } else {
                TabHaobanRole tabHaobanRole = new TabHaobanRole();
                tabHaobanRole.setRoleName(haobanRoleQDTO.getRoleName());
                tabHaobanRole.setModifierId(login.getClerkId());
                tabHaobanRole.setModifierName(login.getClerkName());
                haobanRoleService.update(tabHaobanRole);
            }
        }
        return ServiceResponse.success();
    }

    @Override
    public ServiceResponse getByEnterpriseIdAndClerkType(String enterpriseId, String wxEnterpriseId, Integer clerkType) {
        List<HaobanRoleBO> haobanRoleBOList = haobanRoleService.getByEnterpriseIdAndClerkType(enterpriseId, wxEnterpriseId, clerkType);
        return ServiceResponse.success(haobanRoleBOList);
    }
}
