package com.gic.haoban.manage.service.service.role;

import com.gic.haoban.manage.service.entity.role.TabHaobanRole;
import com.gic.haoban.manage.service.pojo.bo.role.HaobanRoleBO;

import java.util.List;

/**
 * 好办小程序权限(TabHaobanRole)表服务接口
 *
 * @author mozhu
 * @since 2022-09-06 16:35:10
 */
public interface HaobanRoleService {

    /**
     * 通过ID查询单条数据
     *
     * @param roleId 主键
     * @return 实例对象
     */
    TabHaobanRole queryById(Long roleId);

    /**
     * 新增数据
     *
     * @param tabHaobanRole 实例对象
     * @return 实例对象
     */
    TabHaobanRole insert(TabHaobanRole tabHaobanRole);

    /**
     * 插入批量
     *
     * @param tabHaobanRoles 选项卡haoban作用
     * @return int
     * @author mozhu
     * @date 2022-09-07 14:04:38
     */
    int insertBatch(List<TabHaobanRole> tabHaobanRoles);

    /**
     * 修改数据
     *
     * @param tabHaobanRole 实例对象
     * @return 实例对象
     */
    TabHaobanRole update(TabHaobanRole tabHaobanRole);

    /**
     * 通过主键删除数据
     *
     * @param roleId 主键
     * @return 是否成功
     */
    boolean deleteById(Long roleId);

    /**
     * 根据类型查询企业的菜单权限
     *
     * @param enterpriseId   企业标识
     * @param wxEnterpriseId wx企业标识
     * @param clerkType      职员类型
     * @return {@link List }<{@link HaobanRoleBO }>
     * @author mozhu
     * @date 2022-09-07 14:08:19
     */
    List<HaobanRoleBO> getByEnterpriseIdAndClerkType(String enterpriseId, String wxEnterpriseId, Integer clerkType);

    /**
     * 查询菜单id
     *
     * @param menuIds        菜单id
     * @param enterpriseId   企业标识
     * @param wxEnterpriseId wx企业标识
     * @param clerkType      职员类型
     * @return {@link List }<{@link Long }>
     * @author mozhu
     * @date 2022-09-07 14:32:17
     */
    List<Long> queryByMenuIds(List<Long> menuIds,String enterpriseId, String wxEnterpriseId,Integer clerkType);

    /**
     * 查询被删除的菜单id
     *
     * @param menuIds        菜单id
     * @param enterpriseId   企业标识
     * @param wxEnterpriseId wx企业标识
     * @param clerkType      职员类型
     * @return {@link List }<{@link Long }>
     * @author mozhu
     * @date 2022-09-07 14:32:20
     */
    List<Long> queryByUnMenuIds(List<Long> menuIds,String enterpriseId, String wxEnterpriseId,Integer clerkType);


    /**
     * 通过菜单id查询
     *
     * @param menuId         菜单id
     * @param enterpriseId   企业标识
     * @param wxEnterpriseId wx企业标识
     * @param clerkType      职员类型
     * @return {@link Long }
     * @author mozhu
     * @date 2022-09-07 17:03:50
     */
    Long queryByMenuId(Long menuId,String enterpriseId, String wxEnterpriseId,Integer clerkType);

    /**
     * 删除权限
     *
     * @param roleIds 角色id
     * @return int
     * @author mozhu
     * @date 2022-09-07 14:47:18
     */
    void delByRoleIds(List<Long> roleIds);

}
