package com.gic.haoban.manage.service.service.role.impl;

import com.gic.commons.util.EntityUtil;
import com.gic.commons.util.UniqueIdUtils;
import com.gic.haoban.manage.service.dao.mapper.role.TabHaobanRoleMapper;
import com.gic.haoban.manage.service.entity.role.TabHaobanRole;
import com.gic.haoban.manage.service.pojo.bo.role.HaobanRoleBO;
import com.gic.haoban.manage.service.service.role.HaobanRoleService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Date;
import java.util.List;

/**
 * 好办小程序权限(TabHaobanRole)表服务实现类
 *
 * @author mozhu
 * @since 2022-09-06 16:35:10
 */
@Service
public class HaobanRoleServiceImpl implements HaobanRoleService {

    @Autowired
    private TabHaobanRoleMapper tabHaobanRoleMapper;

    /**
     * 通过ID查询单条数据
     *
     * @param roleId 主键
     * @return 实例对象
     */
    @Override
    public TabHaobanRole queryById(Long roleId) {
        return this.tabHaobanRoleMapper.queryById(roleId);
    }


    /**
     * 新增数据
     *
     * @param tabHaobanRole 实例对象
     * @return 实例对象
     */
    @Override
    public TabHaobanRole insert(TabHaobanRole tabHaobanRole) {
        tabHaobanRole.setRoleId(UniqueIdUtils.uniqueLong());
        tabHaobanRole.setCreateTime(new Date());
        tabHaobanRole.setUpdateTime(new Date());
        this.tabHaobanRoleMapper.insert(tabHaobanRole);
        return tabHaobanRole;
    }

    @Override
    public int insertBatch(List<TabHaobanRole> tabHaobanRoles) {
        tabHaobanRoles.forEach(c->{
            c.setRoleId(UniqueIdUtils.uniqueLong());
            c.setCreateTime(new Date());
            c.setUpdateTime(new Date());
        });
        return tabHaobanRoleMapper.insertBatch(tabHaobanRoles);
    }

    /**
     * 修改数据
     *
     * @param tabHaobanRole 实例对象
     * @return 实例对象
     */
    @Override
    public TabHaobanRole update(TabHaobanRole tabHaobanRole) {
        tabHaobanRole.setUpdateTime(new Date());
        this.tabHaobanRoleMapper.update(tabHaobanRole);
        return this.queryById(tabHaobanRole.getRoleId());
    }

    /**
     * 通过主键删除数据
     *
     * @param roleId 主键
     * @return 是否成功
     */
    @Override
    public boolean deleteById(Long roleId) {
        return false;
    }

    @Override
    public List<HaobanRoleBO> getByEnterpriseIdAndClerkType(String enterpriseId, String wxEnterpriseId, Integer clerkType) {
        List<TabHaobanRole> haobanRoles = tabHaobanRoleMapper.getByEnterpriseIdAndClerkType(enterpriseId, wxEnterpriseId, clerkType);
        return EntityUtil.changeEntityListNew(HaobanRoleBO.class,haobanRoles);
    }

    @Override
    public List<Long> queryByMenuIds(List<Long> menuIds, String enterpriseId, String wxEnterpriseId, Integer clerkType) {
        return tabHaobanRoleMapper.queryByMenuIds(menuIds,enterpriseId,wxEnterpriseId,clerkType);
    }

    @Override
    public List<Long> queryByUnMenuIds(List<Long> menuIds, String enterpriseId, String wxEnterpriseId, Integer clerkType) {
        return tabHaobanRoleMapper.queryByUnMenuIds(menuIds,enterpriseId,wxEnterpriseId,clerkType);
    }

    @Override
    public Long queryByMenuId(Long menuId, String enterpriseId, String wxEnterpriseId, Integer clerkType) {
        return tabHaobanRoleMapper.queryByMenuId(menuId,enterpriseId,wxEnterpriseId,clerkType);
    }

    @Override
    public void delByRoleIds(List<Long> roleIds) {
        for (Long roleId : roleIds) {
            TabHaobanRole tabHaobanRole = new TabHaobanRole();
            tabHaobanRole.setStatusFlag(0);
            tabHaobanRole.setRoleId(roleId);
            tabHaobanRoleMapper.update(tabHaobanRole);
        }
    }
}
